.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2019 Jean-Sebastien SUZANNE <js.suzanne@gmail.com>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

.. Anyblok Pyramid Rest Api documentation master file, created by
   sphinx-quickstart on Fri Sep 22 12:52:36 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Anyblok Pyramid Rest Api's documentation!
====================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   FRONT
   memento
   apidoc
   CHANGES
   LICENSE

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
